package com.fs.project.service;

import java.util.List;
import com.fs.project.domain.ProjectPermission;

/**
 * 项目权限Service接口
 * 
 * @author fs
 * @date 2025-12-30
 */
public interface IProjectPermissionService 
{
    /**
     * 查询项目权限
     * 
     * @param id 项目权限主键
     * @return 项目权限
     */
    public ProjectPermission selectProjectPermissionById(Long id);

    /**
     * 查询项目权限列表
     * 
     * @param projectPermission 项目权限
     * @return 项目权限集合
     */
    public List<ProjectPermission> selectProjectPermissionList(ProjectPermission projectPermission);

    /**
     * 新增项目权限
     * 
     * @param projectPermission 项目权限
     * @return 结果
     */
    public int insertProjectPermission(ProjectPermission projectPermission);

    /**
     * 修改项目权限
     * 
     * @param projectPermission 项目权限
     * @return 结果
     */
    public int updateProjectPermission(ProjectPermission projectPermission);

    /**
     * 批量删除项目权限
     * 
     * @param ids 需要删除的项目权限主键集合
     * @return 结果
     */
    public int deleteProjectPermissionByIds(Long[] ids);

    /**
     * 删除项目权限信息
     * 
     * @param id 项目权限主键
     * @return 结果
     */
    public int deleteProjectPermissionById(Long id);
}
